@@ -8,11 +8,8 @@ from bruteloops.db_manager import csv_split
 from functools import wraps
 from random import randint
 from inspect import getargspec
-from logging import getLogger,INFO
 import pdb
 
-brute_logger = getLogger('BruteLoops.example.shortcuts.http')
-
 warnings.filterwarnings('ignore')
 PROXY_FORMAT='<http|https>:<Proxy URI>'
 PROXY_EXAMPLE='https:http://127.0.0.1:8080'
